#!/usr/bin/python2

import os, sys
import argparse
import boto.ec2


class AWSClient:
    
    def __init__(self, key_id, secret_key):
        self._key_id = key_id
        self._secret_key = secret_key
        self._inst_list = []
    
    def update_instance_info(self):
        for r in boto.ec2.regions():
            conn = boto.ec2.connect_to_region(r.name, 
                aws_access_key_id=self._key_id, 
                aws_secret_access_key=self._secret_key)

            try:
                aws_inst_list = conn.get_only_instances()
            except:
                pass

            for i in aws_inst_list:
                self._inst_list.append( { 'id': i.id, 'name': i.tags['Name'], 'region': r.name, 'state':i.state} )
            
    def status(self):
        for inst in self._inst_list:
            print inst

    def start(self, inst_id):
        for i in self._inst_list:
            if i['id'] == inst_id:
                conn = boto.ec2.connect_to_region(i['region'],
                    aws_access_key_id=self._key_id, 
                    aws_secret_access_key=self._secret_key)
                conn.start_instances(inst_id)
                return
        
        print "Failed to find instance with specified ID"
        sys.exit(1)

    def stop(self, inst_id):
        for i in self._inst_list:
            if i['id'] == inst_id:
                conn = boto.ec2.connect_to_region(i['region'],
                    aws_access_key_id=self._key_id, 
                    aws_secret_access_key=self._secret_key)
                conn.stop_instances(inst_id)
                return
        print "Failed to find instance with specified ID"
        sys.exit(1)


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("-r", "--region", help="Specify a region (otherwise check all regions)", dest="region", default="")
    parser.add_argument("-i", "--id", help="Instance ID (required for start|stop)", dest="inst_id")
    parser.add_argument("command", metavar="COMMAND", help="Command to run [status|start|stop]")
    args = parser.parse_args()

    if (args.command == "status"):
        pass
    elif (args.command == "start") or \
        (args.command == "stop"):
        if args.inst_id is None:
            parser.print_help()
            sys.exit(1)
    else:
        parser.print_help()
        sys.exit(1)
    
    key_id = os.environ.get('AWS_ACCESS_KEY_ID')
    if key_id is None:
        print "Expected to find AWS_ACCESS_KEY_ID in the environment"
        sys.exit(1)
    secret_key = os.environ.get('AWS_SECRET_ACCESS_KEY')
    if secret_key is None:
        print "Expected to find AWS_SECRET_ACCESS_KEY in the environment"
        sys.exit(1)

    client = AWSClient(key_id, secret_key)
    client.update_instance_info()
    
    if args.command == "status":
        client.status()
        return
    
    if args.command == "start":
        client.start(args.inst_id)
        return

    if args.command == "stop":
        client.stop(args.inst_id)
        return

    return
    
        

if __name__ == "__main__":
    main()

